# Copyright 2025 TigerGraph Inc.
# Licensed under the Apache License, Version 2.0.
# See the LICENSE file or https://www.apache.org/licenses/LICENSE-2.0
#
# Permission is granted to use, copy, modify, and distribute this software
# under the License. The software is provided "AS IS", without warranty.

from .base_config import BaseConfig
from .graph_db import (
    # configurations for TigerGraph server
    TigerGraphConnectionConfig,
    # configurations for graph schema
    DataType,
    AttributeSchema,
    AttributesType,
    VectorAttributeSchema,
    VectorAttributesType,
    NodeSchema,
    EdgeSchema,
    GraphSchema,
    create_node_schema,
    create_edge_schema,
    # configurations for loading job
    QuoteType,
    CsvParsingOptions,
    NodeMappingConfig,
    EdgeMappingConfig,
    FileConfig,
    LoadingJobConfig,
)
from .query import (
    NodeSpec,
    EdgeSpec,
    NeighborSpec,
)

from .settings import (
    Settings,
    BaseLLMConfig,
    OpenAIConfig,
    BaseEmbeddingConfig,
    OpenAIEmbeddingConfig,
    BaseVectorDBConfig,
    TigerVectorConfig,
    NanoVectorDBConfig,
    BaseChatConfig,
    OpenAIChatConfig,
)

__all__ = [
    # base class for configurations
    "BaseConfig",
    # configurations for TigerGraph server
    "TigerGraphConnectionConfig",
    # configurations for graph schema
    "DataType",
    "AttributeSchema",
    "AttributesType",
    "VectorAttributeSchema",
    "VectorAttributesType",
    "NodeSchema",
    "EdgeSchema",
    "GraphSchema",
    "create_node_schema",
    "create_edge_schema",
    # configurations for loading job
    "QuoteType",
    "CsvParsingOptions",
    "NodeMappingConfig",
    "EdgeMappingConfig",
    "FileConfig",
    "LoadingJobConfig",
    # configurations for TigerGraph connection
    "TigerGraphConnectionConfig",
    # configurations for queries
    "NodeSpec",
    "NeighborSpec",
    # configurations for GraphRAG
    "Settings",
    "BaseLLMConfig",
    "OpenAIConfig",
    "BaseEmbeddingConfig",
    "OpenAIEmbeddingConfig",
    "BaseVectorDBConfig",
    "TigerVectorConfig",
    "NanoVectorDBConfig",
    "BaseChatConfig",
    "OpenAIChatConfig",
]
